//-----------------------------------------------------------------------------
// display.m
//
// controls the various display options of J5
//
// created by FrisbeeMonkey
//-----------------------------------------------------------------------------

#include "../../../lib/std.mi"

Function ChangeModes();
Function initSpkr(Layer Speaker);
Function Thump(int Left, int Right);


Global Button DispBtn;
Global Group UtilityGrp, VisGrp, cBtnGrp;
Global Int DispMode; //normal, vis, spk, vis&spk, vis&spk&no
Global Layer LeftSpeaker, RightSpeaker;
Global Timer SpeakerTmr;
Global Double LeftValue, RightValue;
Global PopupMenu DispMenu;

System.onScriptLoaded() {

	Group MainNormal = getScriptGroup();
	DispBtn = MainNormal.findObject("DispMenu");
	UtilityGrp = MainNormal.findObject("player.normal.group.display.main");
	VisGrp = MainNormal.findObject("player.normal.group.display.vis");
	cBtnGrp = MainNormal.findObject("player.normal.group.cButtons");
	LeftSpeaker = MainNormal.findObject("SpeakerLeftIn");
	RightSpeaker = MainNormal.findObject("SpeakerRightIn");

	initSpkr(LeftSpeaker);
	initSpkr(RightSpeaker);

	DispMenu = new PopupMenu;
	DispMenu.addCommand("Normal",1,0,0);
	DispMenu.addCommand("Vis Only",2,0,0);
	DispMenu.addCommand("Speakers Only",3,0,0);
	DispMenu.addCommand("V & S",4,0,0);
	DispMenu.addCommand("V & S & Hide cButtons",5,0,0);

	DispMode = getPrivateInt("J5", "DispMode", 0);
	ChangeModes();
}

initSpkr(Layer Speaker) {
	Speaker.fx_setBgFx(0);
	Speaker.fx_setWrap(0);
	Speaker.fx_setBilinear(1);
	Speaker.fx_setAlphaMode(0);
	Speaker.fx_setGridSize(1,1);
	Speaker.fx_setRect(0);
	Speaker.fx_setClear(1);
	Speaker.fx_setLocalized(1);
	Speaker.fx_setRealtime(1);
	Speaker.fx_setSpeed(30);
}

LeftSpeaker.fx_onGetPixelD(double r, double d, double x, double y) {
	return (d * (1 -(0.65 * LeftValue)));
}

RightSpeaker.fx_onGetPixelD(double r, double d, double x, double y) {
	return (d * (1 -(0.65 * RightValue)));
}


LeftSpeaker.fx_onFrame() {
	LeftValue = System.getLeftVUMeter()/255;
}

RightSpeaker.fx_onFrame() {
	RightValue = System.getRightVUMeter()/255;
}

System.onPlay() {
	if (DispMode > 1) {
		LeftSpeaker.fx_setEnabled(1);
		RightSpeaker.fx_setEnabled(1);
	}
}

System.onResume() {
	if (DispMode > 1) {
		LeftSpeaker.fx_setEnabled(1);
		RightSpeaker.fx_setEnabled(1);
	}
}

System.onStop() {
	LeftSpeaker.fx_setEnabled(0);
	RightSpeaker.fx_setEnabled(0);
}

System.onPause() {
	LeftSpeaker.fx_setEnabled(0);
	RightSpeaker.fx_setEnabled(0);
}

ChangeModes() {
	if (DispMode == 0) {//normal
		UtilityGrp.show();
		VisGrp.hide();
		LeftSpeaker.fx_setEnabled(0);
		RightSpeaker.fx_setEnabled(0);
		cBtnGrp.setTargetY(123);
		cBtnGrp.setTargetSpeed(0.8);
		cBtnGrp.gotoTarget();

	} else if (DispMode == 1) {//vis
		UtilityGrp.hide();
		VisGrp.show();
		LeftSpeaker.fx_setEnabled(0);
		RightSpeaker.fx_setEnabled(0);
		cBtnGrp.setTargetY(123);
		cBtnGrp.setTargetSpeed(0.8);
		cBtnGrp.gotoTarget();

	} else if (DispMode == 2) {//speaker
		UtilityGrp.show();
		VisGrp.hide();
		LeftSpeaker.fx_setEnabled(1);
		RightSpeaker.fx_setEnabled(1);
		cBtnGrp.setTargetY(123);
		cBtnGrp.setTargetSpeed(0.8);
		cBtnGrp.gotoTarget();

	} else if (DispMode == 3) {//vis & speaker
		UtilityGrp.hide();
		VisGrp.show();
		LeftSpeaker.fx_setEnabled(1);
		RightSpeaker.fx_setEnabled(1);
		cBtnGrp.setTargetY(123);
		cBtnGrp.setTargetSpeed(0.8);
		cBtnGrp.gotoTarget();

	} else {				   //vis & speaker && hide cBtns
		UtilityGrp.hide();
		VisGrp.show();
		LeftSpeaker.fx_setEnabled(1);
		RightSpeaker.fx_setEnabled(1);
		cBtnGrp.setTargetY(75);
		cBtnGrp.setTargetSpeed(0.8);
		cBtnGrp.gotoTarget();

	}
}

DispBtn.onRightButtonUp(int x, int y) {

	DispMenu.checkCommand(1,(!DispMode));
	DispMenu.checkCommand(2,(DispMode == 1));
	DispMenu.checkCommand(3,(DispMode == 2));
	DispMenu.checkCommand(4,(DispMode == 3));
	DispMenu.checkCommand(5,(DispMode == 4));

	int Choice = DispMenu.popAtMouse();

	if (Choice==1) {
		DispMode = 0;
	} else if (Choice==2) {
		DispMode = 1;
	} else if (Choice==3) {
		DispMode = 2;
	} else if (Choice==4) {
		DispMode = 3;
	} else if (Choice==5) {
		DispMode = 4;
	}

	ChangeModes();

	complete;
}

DispBtn.onLeftButtonUp(int x, int y) {
	DispMode = DispMode + 1;
	if (DispMode > 4) {
		DispMode = 0;
	}
	ChangeModes();
}

System.onScriptUnloading() {
	delete DispMenu;
	delete SpeakerTmr;
	setPrivateInt("J5", "DispMode", DispMode);
}